@@ -6,7 +6,7 @@ import pandas as pd
 def missing_data_check(column_df):
 
     
-    missing_data = column_df.isnull()
+    missing_data = column_df[column_df != ""]
 
     if missing_data.any():
 
@@ -24,8 +24,5 @@ def missing_data_check(column_df):
         return True
 
 
-if __name__ == "__main__":
-    print(
-        missing_data_check(
-            "COH_Deliveries_TEMPLATE_22_23_Example_Data (1) (1).xlsx",
-            "Unique_Farmers", "Farmer Group Code"))
+
+
