@@ -9,9 +9,10 @@ def value_restriction_check(value_restriction_column_df, column_df):
         return value
         
     column_df = column_df.fillna("").astype(str)
-    value_restriction_column_df = value_restriction_column_df.apply(lowercase_if_string)
-    column_df = column_df.apply(lowercase_if_string)
     non_empty_column_df = column_df[column_df != ""]
+    value_restriction_column_df = value_restriction_column_df.apply(lowercase_if_string)
+    non_empty_column_df = non_empty_column_df.apply(lowercase_if_string)
+    
     is_in_lookup_df = non_empty_column_df.isin(value_restriction_column_df)
 
     
